@@ -15,6 +15,12 @@ from .tools.document_qa import document_qa
 from .tools.md_to_pdf import md_to_pdf
 from .tools.web_search import web_search, tavily_web_search, exa_web_search, brave_web_search
 from .tools.visit_webpage import visit_webpage
+from .tools.bitflip import (
+    extract_bitflip_info,
+    generate_research_proposal,
+    score_research_proposals,
+)
+
 
 load_dotenv()
 
@@ -27,7 +33,7 @@ def find_free_port() -> int:
                 return port
         except Exception:
             continue
-    return 5000
+    raise RuntimeError("No free port in range 5000-6000 found")
 
 
 def run(
@@ -36,6 +42,8 @@ def run(
     mount_path: str = "/",
     streamable_http_path: str = "/mcp",
     transport: Literal["stdio", "sse", "streamable-http"] = "streamable-http",
+    disable_web_search_tools: bool = False,
+    disable_llm_tools: bool = False,
 ) -> None:
     server = FastMCP(
         "Academia MCP",
@@ -53,15 +61,20 @@ def run(
     server.add_tool(md_to_pdf)
     server.add_tool(visit_webpage)
 
-    if os.getenv("TAVILY_API_KEY"):
-        server.add_tool(tavily_web_search)
-    if os.getenv("EXA_API_KEY"):
-        server.add_tool(exa_web_search)
-    if os.getenv("BRAVE_API_KEY"):
-        server.add_tool(brave_web_search)
-    if os.getenv("EXA_API_KEY") or os.getenv("BRAVE_API_KEY") or os.getenv("TAVILY_API_KEY"):
-        server.add_tool(web_search)
-    if os.getenv("OPENROUTER_API_KEY"):
+    if not disable_web_search_tools:
+        if os.getenv("TAVILY_API_KEY"):
+            server.add_tool(tavily_web_search)
+        if os.getenv("EXA_API_KEY"):
+            server.add_tool(exa_web_search)
+        if os.getenv("BRAVE_API_KEY"):
+            server.add_tool(brave_web_search)
+        if os.getenv("EXA_API_KEY") or os.getenv("BRAVE_API_KEY") or os.getenv("TAVILY_API_KEY"):
+            server.add_tool(web_search)
+
+    if not disable_llm_tools and os.getenv("OPENROUTER_API_KEY"):
+        server.add_tool(extract_bitflip_info)
+        server.add_tool(generate_research_proposal)
+        server.add_tool(score_research_proposals)
         server.add_tool(document_qa)
 
     if port is None:
